Learn R Programming

Rtropical (version 1.2.1)

coef.cv.tropsvm: Extract Optimal Tropical Hyperplane from a cv.tropsvm object

Description

Obtain the optimal tropical hyperplane in the form of vectors from a cv.tropsvm object.

Usage

# S3 method for cv.tropsvm
coef(object, ...)

Arguments

object

a fitted "cv.tropsvm" object.

Not used. Other arguments.

Value

An output of the apex of the fitted optimal tropical hyperplane.