Learn R Programming

Rtropical (version 1.2.1)

coef.tropsvm: Extract Optimal Tropical Hyperplane from a tropsvm object

Description

Obtain the optimal tropical hyperplane in the form of vectors from a tropsvm object.

Usage

# S3 method for tropsvm
coef(object, ...)

Arguments

object

a fitted "tropsvm" object.

Not used. Other arguments.

Value

An output of the apex of the fitted optimal tropical hyperplane.