powered by
Dimension Reduction by Isometry
polytope_iso(D, P)
a data matrix of size s x e whose rows are vertices of a tropical polytope.
a vector of a point in row spaces of D.
D
A vector of a point corresponding to P in column span of D.
P