Read NEXUS-formatted trees from two categories into a data matrix
read.nexus.to.data.matrix(data.file1, data.file2)A data set with trees from one category.
A data set with trees from the other category.
A data matrix with the first x rows corresponding the x trees in the first file and the last y rows are the trees from the second file.