Learn R Programming

Rtropical (version 1.2.1)

summary.cv.tropsvm: Summarize an Analysis of Cross-Validated Tropical Support Vector Machine

Description

Return a summary with a more detailed explanation of the object "cv.tropsvm".

Usage

# S3 method for cv.tropsvm
summary(object, ...)

Arguments

object

a fitted "cv.tropsvm" object.

Not used. Other arguments to summary.

Value

A summary of the crucial information of a tropical support vector machine is printed, including the selected best assignment and classification methods and the validation accuracy of each data fold. The summary section of classification methods specifies the sectors and their intersections used to classify points of two different categories.

See Also

predict, coef and the cv.tropsvm function.

Examples

Run this code
# NOT RUN {
# data generation
library(Rfast)
e <- 20
n <- 10
N <- 10
s <- 5
x <- rbind(
  rmvnorm(n, mu = c(5, -5, rep(0, e - 2)), sigma = diag(s, e)),
  rmvnorm(n, mu = c(-5, 5, rep(0, e - 2)), sigma = diag(s, e))
)
y <- as.factor(c(rep(1, n), rep(2, n)))
newx <- rbind(
  rmvnorm(N, mu = c(5, -5, rep(0, e - 2)), sigma = diag(s, e)),
  rmvnorm(N, mu = c(-5, 5, rep(0, e - 2)), sigma = diag(s, e))
)
newy <- as.factor(rep(c(1, 2), each = N))

# train the tropical svm with cross-validation
cv_tropsvm_fit <- cv.tropsvm(x, y, parallel = FALSE)

summary(cv_tropsvm_fit)
# }

Run the code above in your browser using DataLab