Compute the tropical Fermat-Weber (FW) point for a given data matrix.
The FW point minimizes the summed tropical distance to the trees described
in the data matrix.
Usage
tropFW(x)
Arguments
x
a data matrix, of dimension nobs x nvars; each row is an observation vector.
Value
A list containing:
fw
The fermat-weber point.
distsum
The sum of distance from each observation to the fermat-weber point.