powered by
Computes the cophenetic distance and outputs them in a vector of a phylogenetic tree in phylo object
phylo
# S3 method for phylo as.vector(x, mode = "any")
A object of class phylo
The same as base::as.vector. But only numeric output in vector form is accepted for other functions in Rtropical
base::as.vector
Rtropical
A vector with its elements the distance between two leaves of the tree.
# NOT RUN { library(ape) tree <- rcoal(5) tree_vec <- as.vector(tree) # }
Run the code above in your browser using DataLab