linsp_to_poly: Convert Tropical Linear Space to Convex Hull
Description
Convert Tropical Linear Space to Convex Hull
Usage
linsp_to_poly(V)
Arguments
V
a data matrix, of dimension s x e, with each row a basis of tropical linear space.
e is the dimension of the tropical space and s is the dimension of the linear space.